[−][src]Enum unicode_types::medefaidrin::Medefaidrin
An enum to represent all characters in the Medefaidrin block.
Variants
CapitalLetterM\u{16e40}: '𖹀'
CapitalLetterS\u{16e41}: '𖹁'
CapitalLetterV\u{16e42}: '𖹂'
CapitalLetterW\u{16e43}: '𖹃'
CapitalLetterAtiu\u{16e44}: '𖹄'
CapitalLetterZ\u{16e45}: '𖹅'
CapitalLetterKp\u{16e46}: '𖹆'
CapitalLetterP\u{16e47}: '𖹇'
CapitalLetterT\u{16e48}: '𖹈'
CapitalLetterG\u{16e49}: '𖹉'
CapitalLetterF\u{16e4a}: '𖹊'
CapitalLetterI\u{16e4b}: '𖹋'
CapitalLetterK\u{16e4c}: '𖹌'
CapitalLetterA\u{16e4d}: '𖹍'
CapitalLetterJ\u{16e4e}: '𖹎'
CapitalLetterE\u{16e4f}: '𖹏'
CapitalLetterB\u{16e50}: '𖹐'
CapitalLetterC\u{16e51}: '𖹑'
CapitalLetterU\u{16e52}: '𖹒'
CapitalLetterYu\u{16e53}: '𖹓'
CapitalLetterL\u{16e54}: '𖹔'
CapitalLetterQ\u{16e55}: '𖹕'
CapitalLetterHp\u{16e56}: '𖹖'
CapitalLetterNy\u{16e57}: '𖹗'
CapitalLetterX\u{16e58}: '𖹘'
CapitalLetterD\u{16e59}: '𖹙'
CapitalLetterOe\u{16e5a}: '𖹚'
CapitalLetterN\u{16e5b}: '𖹛'
CapitalLetterR\u{16e5c}: '𖹜'
CapitalLetterO\u{16e5d}: '𖹝'
CapitalLetterAi\u{16e5e}: '𖹞'
CapitalLetterY\u{16e5f}: '𖹟'
SmallLetterM\u{16e60}: '𖹠'
SmallLetterS\u{16e61}: '𖹡'
SmallLetterV\u{16e62}: '𖹢'
SmallLetterW\u{16e63}: '𖹣'
SmallLetterAtiu\u{16e64}: '𖹤'
SmallLetterZ\u{16e65}: '𖹥'
SmallLetterKp\u{16e66}: '𖹦'
SmallLetterP\u{16e67}: '𖹧'
SmallLetterT\u{16e68}: '𖹨'
SmallLetterG\u{16e69}: '𖹩'
SmallLetterF\u{16e6a}: '𖹪'
SmallLetterI\u{16e6b}: '𖹫'
SmallLetterK\u{16e6c}: '𖹬'
SmallLetterA\u{16e6d}: '𖹭'
SmallLetterJ\u{16e6e}: '𖹮'
SmallLetterE\u{16e6f}: '𖹯'
SmallLetterB\u{16e70}: '𖹰'
SmallLetterC\u{16e71}: '𖹱'
SmallLetterU\u{16e72}: '𖹲'
SmallLetterYu\u{16e73}: '𖹳'
SmallLetterL\u{16e74}: '𖹴'
SmallLetterQ\u{16e75}: '𖹵'
SmallLetterHp\u{16e76}: '𖹶'
SmallLetterNy\u{16e77}: '𖹷'
SmallLetterX\u{16e78}: '𖹸'
SmallLetterD\u{16e79}: '𖹹'
SmallLetterOe\u{16e7a}: '𖹺'
SmallLetterN\u{16e7b}: '𖹻'
SmallLetterR\u{16e7c}: '𖹼'
SmallLetterO\u{16e7d}: '𖹽'
SmallLetterAi\u{16e7e}: '𖹾'
SmallLetterY\u{16e7f}: '𖹿'
DigitZero\u{16e80}: '𖺀'
DigitOne\u{16e81}: '𖺁'
DigitTwo\u{16e82}: '𖺂'
DigitThree\u{16e83}: '𖺃'
DigitFour\u{16e84}: '𖺄'
DigitFive\u{16e85}: '𖺅'
DigitSix\u{16e86}: '𖺆'
DigitSeven\u{16e87}: '𖺇'
DigitEight\u{16e88}: '𖺈'
DigitNine\u{16e89}: '𖺉'
NumberTen\u{16e8a}: '𖺊'
NumberEleven\u{16e8b}: '𖺋'
NumberTwelve\u{16e8c}: '𖺌'
NumberThirteen\u{16e8d}: '𖺍'
NumberFourteen\u{16e8e}: '𖺎'
NumberFifteen\u{16e8f}: '𖺏'
NumberSixteen\u{16e90}: '𖺐'
NumberSeventeen\u{16e91}: '𖺑'
NumberEighteen\u{16e92}: '𖺒'
NumberNineteen\u{16e93}: '𖺓'
DigitOneAlternateForm\u{16e94}: '𖺔'
DigitTwoAlternateForm\u{16e95}: '𖺕'
DigitThreeAlternateForm\u{16e96}: '𖺖'
Comma\u{16e97}: '𖺗'
FullStop\u{16e98}: '𖺘'
SymbolAiva\u{16e99}: '𖺙'
ExclamationOh\u{16e9a}: '𖺚'
Methods
impl Medefaidrin[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case